@@ -26,13 +26,16 @@
 # delete this exception statement from your version.
 
 from gi.repository import Tracker
+from itertools import chain
 import logging
+import time
 logger = logging.getLogger(__name__)
 tabbing = 0
 
 
 def log(fn):
-    from itertools import chain
+    if logger.getEffectiveLevel() > logging.DEBUG:
+        return fn
 
     def wrapped(*v, **k):
         global tabbing
@@ -40,16 +43,36 @@ def log(fn):
         module = fn.__module__
         params = ", ".join(map(repr, chain(v, k.values())))
 
-        logger.debug("%s%s.%s(%s)" % ('|' * tabbing, module, name, params))
+        logger.debug("%s%s.%s(%s)", '|' * tabbing, module, name, params)
         tabbing += 1
         retval = fn(*v, **k)
         tabbing -= 1
-        logger.debug("%sreturned %s" % ('|' * tabbing, retval))
+        logger.debug("%sreturned %s", '|' * tabbing, retval)
 
         return retval
     return wrapped
 
 
+def RateLimited(maxPerSecond):
+    minInterval = 1.0 / float(maxPerSecond)
+
+    def decorate(func):
+        lastTimeCalled = [0.0]
+
+        def rateLimitedFunction(*args, **kargs):
+            elapsed = time.clock() - lastTimeCalled[0]
+            leftToWait = minInterval - elapsed
+            if leftToWait > 0:
+                return
+            ret = func(*args, **kargs)
+            lastTimeCalled[0] = time.clock()
+            return ret
+
+        return rateLimitedFunction
+
+    return decorate
+
+
 class TrackerWrapper:
     class __TrackerWrapper:
         def __init__(self):
@@ -57,7 +80,7 @@ class TrackerWrapper:
                 self.tracker = Tracker.SparqlConnection.get(None)
             except Exception as e:
                 from sys import exit
-                logger.error("Cannot connect to tracker, error '%s'\Exiting" % str(e))
+                logger.error("Cannot connect to tracker, error '%s'\Exiting", str(e))
                 exit(1)
 
         def __str__(self):
