@@ -28,7 +28,7 @@
 # delete this exception statement from your version.
 
 
-from gi.repository import Gtk, GdkPixbuf, Gio, GLib, Gdk, MediaArt
+from gi.repository import Gtk, GdkPixbuf, GObject, Gio, GLib, Gdk, MediaArt
 from gettext import gettext as _
 import cairo
 from math import pi
@@ -37,10 +37,9 @@ from threading import Thread, Lock
 from gnomemusic import log
 from gnomemusic.grilo import grilo
 import logging
-from queue import Queue
 logger = logging.getLogger(__name__)
 
-WORKER_THREADS = 2
+THREAD_QUEUE = []
 
 
 @log
@@ -78,12 +77,16 @@ def _make_icon_frame(pixbuf, path=None):
     return border_pixbuf
 
 
-class AlbumArtCache:
+class AlbumArtCache(GObject.GObject):
     instance = None
     blacklist = {}
     itr_queue = []
     threading_lock = Lock()
 
+    __gsignals__ = {
+        'thread-added': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+    }
+
     @classmethod
     def get_default(self):
         if not self.instance:
@@ -115,34 +118,26 @@ class AlbumArtCache:
 
         return title
 
-    def worker(self, id):
-        while True:
-            try:
-                item = self.thread_queue.get()
-                item.setDaemon(True)
-                item.start()
-                item.join(30)
-                self.thread_queue.task_done()
-            except Exception as e:
-                logger.warn("worker %d item %s: error %s" % (id, item, str(e)))
+    def worker(self, object, id):
+        try:
+            item = THREAD_QUEUE[id]
+            item.setDaemon(True)
+            item.start()
+            item.join()
+        except Exception as e:
+            logger.warn("worker item %s: error %s",  item, str(e))
 
     @log
     def __init__(self):
+        GObject.GObject.__init__(self)
         try:
             self.cacheDir = os.path.join(GLib.get_user_cache_dir(), 'media-art')
             if not os.path.exists(self.cacheDir):
                 Gio.file_new_for_path(self.cacheDir).make_directory(None)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
 
-        try:
-            self.thread_queue = Queue()
-            for i in range(WORKER_THREADS):
-                t = Thread(target=self.worker, args=(i,))
-                t.setDaemon(True)
-                t.start()
-        except Exception as e:
-            logger.warn("Error: %s" % e)
+        self.connect('thread-added', self.worker)
 
     @log
     def get_default_icon(self, width, height, is_loading=False):
@@ -185,9 +180,10 @@ class AlbumArtCache:
                     self.itr_queue.append(itr.user_data)
 
             t = Thread(target=self.lookup_worker, args=(item, width, height, callback, itr, artist, album))
-            self.thread_queue.put(t)
+            THREAD_QUEUE.append(t)
+            self.emit('thread-added', len(THREAD_QUEUE)-1)
         except Exception as e:
-            logger.warn("Error: %s, %s" % (e.__class__, e))
+            logger.warn("Error: %s, %s", e.__class__, e)
 
     @log
     def lookup_worker(self, item, width, height, callback, itr, artist, album):
@@ -212,7 +208,7 @@ class AlbumArtCache:
             pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(path, width, height, True)
             self.finish(item, _make_icon_frame(pixbuf), path, callback, itr, width, height)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
 
     @log
     def finish(self, item, pixbuf, path, callback, itr, width=-1, height=-1, artist=None, album=None):
@@ -230,7 +226,7 @@ class AlbumArtCache:
                 item.set_thumbnail(GLib.filename_to_uri(path, None))
             GLib.idle_add(callback, pixbuf, path, itr)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
 
     @log
     def cached_thumb_not_found(self, item, width, height, path, callback, itr, artist, album):
@@ -242,9 +238,10 @@ class AlbumArtCache:
                 return
 
             t = Thread(target=self.download_worker, args=(item, width, height, path, callback, itr, artist, album, uri))
-            self.thread_queue.put(t)
+            THREAD_QUEUE.append(t)
+            self.emit('thread-added', len(THREAD_QUEUE)-1)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
             self.finish(item, None, None, callback, itr, width, height, artist, album)
 
     @log
@@ -256,14 +253,15 @@ class AlbumArtCache:
 
             uri = item.get_thumbnail()
             if uri is None:
-                logger.warn("can't find artwork for album '%s' by %s" % (album, artist))
+                logger.warn("can't find artwork for album '%s' by %s", album, artist)
                 self.finish(item, None, None, callback, itr, width, height, artist, album)
                 return
 
             t = Thread(target=self.download_worker, args=(item, width, height, path, callback, itr, artist, album, uri))
-            self.thread_queue.put(t)
+            THREAD_QUEUE.append(t)
+            self.emit('thread-added', len(THREAD_QUEUE)-1)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
             self.finish(item, None, None, callback, itr, width, height, artist, album)
 
     @log
@@ -274,5 +272,5 @@ class AlbumArtCache:
             src.copy(dest, Gio.FileCopyFlags.OVERWRITE)
             self.lookup_worker(item, width, height, callback, itr, artist, album)
         except Exception as e:
-            logger.warn("Error: %s" % e)
+            logger.warn("Error: %s", e)
             self.finish(item, None, None, callback, itr, width, height, artist, album)
