@@ -210,6 +210,7 @@ class ViewContainer(Gtk.Stack):
 
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
+        self.window.notification.set_timeout(0)
         if not item:
             if remaining == 0:
                 self.window.notification.dismiss()
@@ -288,6 +289,7 @@ class Albums(ViewContainer):
     def _on_changes_pending(self, data=None):
         if (self._init and self.header_bar._selectionMode is False):
             self._offset = 0
+            self._init = True
             self.model.clear()
             self.populate()
             grilo.changes_pending['Albums'] = False
@@ -422,6 +424,7 @@ class Songs(ViewContainer):
         return False
 
     def _add_item(self, source, param, item, remaining=0, data=None):
+        self.window.notification.set_timeout(0)
         if not item:
             if remaining == 0:
                 self.window.notification.dismiss()
@@ -447,10 +450,12 @@ class Songs(ViewContainer):
         cols = list_widget.get_columns()
         cells = cols[0].get_cells()
         cells[2].set_visible(False)
-        now_playing_symbol_renderer = Gtk.CellRendererPixbuf(xalign=1.0)
+        now_playing_symbol_renderer = Gtk.CellRendererPixbuf(xpad=0,
+                                                             xalign=0.5,
+                                                             yalign=0.5)
 
         column_now_playing = Gtk.TreeViewColumn()
-        column_now_playing.set_property('fixed_width', 24)
+        column_now_playing.set_fixed_width(48)
         column_now_playing.pack_start(now_playing_symbol_renderer, False)
         column_now_playing.set_cell_data_func(now_playing_symbol_renderer,
                                               self._on_list_widget_icon_render, None)
@@ -463,9 +468,14 @@ class Songs(ViewContainer):
             height=48,
             ellipsize=Pango.EllipsizeMode.END
         )
-        list_widget.add_renderer(title_renderer,
-                                 self._on_list_widget_title_render, None)
-        cols[0].add_attribute(title_renderer, 'text', 2)
+
+        col = Gtk.TreeViewColumn()
+        col.set_expand(True)
+        col.pack_start(title_renderer, True)
+        col.set_cell_data_func(title_renderer,
+                               self._on_list_widget_title_render, None)
+        col.add_attribute(title_renderer, 'text', 2)
+        list_widget.insert_column(col, 1)
 
         self.star_handler._add_star_renderers(list_widget, cols)
 
@@ -474,25 +484,38 @@ class Songs(ViewContainer):
             xalign=1.0
         )
         duration_renderer.add_class('dim-label')
-        list_widget.add_renderer(duration_renderer,
-                                 self._on_list_widget_duration_render, None)
+
+        col = Gtk.TreeViewColumn()
+        col.pack_start(duration_renderer, False)
+        col.set_cell_data_func(duration_renderer,
+                               self._on_list_widget_duration_render, None)
+        list_widget.append_column(col)
 
         artist_renderer = Gd.StyledTextRenderer(
             xpad=32,
+            width=100,
             ellipsize=Pango.EllipsizeMode.END
         )
         artist_renderer.add_class('dim-label')
-        list_widget.add_renderer(artist_renderer,
-                                 self._on_list_widget_artist_render, None)
-        cols[0].add_attribute(artist_renderer, 'text', 3)
+
+        col = Gtk.TreeViewColumn()
+        col.set_expand(True)
+        col.pack_start(artist_renderer, True)
+        col.set_cell_data_func(artist_renderer,
+                               self._on_list_widget_artist_render, None)
+        col.add_attribute(artist_renderer, 'text', 3)
+        list_widget.append_column(col)
 
         type_renderer = Gd.StyledTextRenderer(
             xpad=32,
+            width=100,
             ellipsize=Pango.EllipsizeMode.END
         )
         type_renderer.add_class('dim-label')
-        list_widget.add_renderer(type_renderer,
-                                 self._on_list_widget_type_render, None)
+
+        col.pack_end(type_renderer, True)
+        col.set_cell_data_func(type_renderer,
+                               self._on_list_widget_type_render, None)
 
     def _on_list_widget_title_render(self, col, cell, model, _iter, data):
         pass
@@ -560,19 +583,14 @@ class Artists (ViewContainer):
         )
         self.artistAlbumsStack.add_named(self._artistAlbumsWidget, "sidebar")
         self.artistAlbumsStack.set_visible_child_name("sidebar")
+        self.view.set_shadow_type(Gtk.ShadowType.IN)
+        self.view.get_style_context().add_class('side-panel')
         self.view.set_hexpand(False)
         self.view.get_generic_view().get_selection().set_mode(
             Gtk.SelectionMode.SINGLE)
         self._grid.attach(self.artistAlbumsStack, 2, 0, 2, 2)
         self._add_list_renderers()
         self.view.get_generic_view().get_style_context().remove_class('content-view')
-        if (Gtk.Settings.get_default().get_property(
-                'gtk_application_prefer_dark_theme')):
-            self.view.get_generic_view().get_style_context().\
-                add_class('artist-panel-dark')
-        else:
-            self.view.get_generic_view().get_style_context().\
-                add_class('artist-panel-white')
         self.show_all()
         self.view.hide()
 
@@ -675,6 +693,7 @@ class Artists (ViewContainer):
 
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
+        self.window.notification.set_timeout(0)
         if item is None:
             if remaining == 0:
                 self.window.notification.dismiss()
@@ -764,9 +783,7 @@ class Playlist(ViewContainer):
 
     @log
     def __init__(self, window, player):
-        self.playlists_sidebar = Gd.MainView(
-            shadow_type=Gtk.ShadowType.NONE
-        )
+        self.playlists_sidebar = Gd.MainView()
 
         ViewContainer.__init__(self, 'playlists', _("Playlists"), window,
                                Gd.MainViewType.LIST, True, self.playlists_sidebar)
@@ -808,7 +825,7 @@ class Playlist(ViewContainer):
         self.playlists_sidebar.set_view_type(Gd.MainViewType.LIST)
         self.playlists_sidebar.set_model(self.playlists_model)
         self.playlists_sidebar.set_hexpand(False)
-        #self.playlists_sidebar.get_style_context().add_class('artist-panel')
+        self.playlists_sidebar.get_style_context().add_class('side-panel')
         self.playlists_sidebar.get_generic_view().get_selection().set_mode(
             Gtk.SelectionMode.SINGLE)
         self.playlists_sidebar.connect('item-activated', self._on_playlist_activated)
@@ -817,13 +834,6 @@ class Playlist(ViewContainer):
         self._grid.child_set_property(self.stack, 'height', 2)
         self._add_sidebar_renderers()
         self.playlists_sidebar.get_generic_view().get_style_context().remove_class('content-view')
-        if (Gtk.Settings.get_default().get_property(
-                'gtk_application_prefer_dark_theme')):
-            self.playlists_sidebar.get_generic_view().get_style_context().\
-                add_class("artist-panel-dark")
-        else:
-            self.playlists_sidebar.get_generic_view().get_style_context().\
-                add_class("artist-panel-white")
 
         self.iter_to_clean = None
         self.iter_to_clean_model = None
@@ -853,10 +863,12 @@ class Playlist(ViewContainer):
         cols = list_widget.get_columns()
         cells = cols[0].get_cells()
         cells[2].set_visible(False)
-        now_playing_symbol_renderer = Gtk.CellRendererPixbuf(xalign=1.0)
+        now_playing_symbol_renderer = Gtk.CellRendererPixbuf(xpad=0,
+                                                             xalign=0.5,
+                                                             yalign=0.5)
 
         column_now_playing = Gtk.TreeViewColumn()
-        column_now_playing.set_property('fixed_width', 24)
+        column_now_playing.set_fixed_width(48)
         column_now_playing.pack_start(now_playing_symbol_renderer, False)
         column_now_playing.set_cell_data_func(now_playing_symbol_renderer,
                                               self._on_list_widget_icon_render, None)
@@ -982,6 +994,7 @@ class Playlist(ViewContainer):
 
     @log
     def _add_playlist_item_to_model(self, item, index=None):
+        self.window.notification.set_timeout(0)
         if index is None:
             index = -1
         if not item:
@@ -1217,7 +1230,7 @@ class Playlist(ViewContainer):
                 # Is the removed track now being played?
                 if self.current_playlist and \
                    playlist.get_id() == self.current_playlist.get_id():
-                    if self.player.currentTrack is not None:
+                    if self.player.currentTrack is not None and self.player.currentTrack.valid():
                         currentTrackpath = self.player.currentTrack.get_path().to_string()
                         if row.path is not None and row.path.to_string() == currentTrackpath:
                             update_playing_track = True
@@ -1327,6 +1340,7 @@ class Search(ViewContainer):
                 self.header_bar, self.selection_toolbar, self.window, True
             )
             self.add(self._artistAlbumsWidget)
+            self._artistAlbumsWidget.show()
 
             self.header_bar.set_state(ToolbarState.SEARCH_VIEW)
             self.header_bar.header_bar.set_title(artist)
@@ -1374,6 +1388,7 @@ class Search(ViewContainer):
 
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
+        self.window.notification.set_timeout(0)
         if data is None:
             return
 
@@ -1464,6 +1479,7 @@ class Search(ViewContainer):
 
     @log
     def populate(self):
+        self._init = True
         self.window._init_loading_notification()
         self.header_bar.set_state(ToolbarState.MAIN)
 
